@@ -5,9 +5,7 @@
 #ifndef LUNARMANAGER_H
 #define LUNARMANAGER_H
 
-#include "lunardbusinterface.h"
 #include "huangliData/dbusdatastruct.h"
-#include "huangliData/lunardatastruct.h"
 
 #include <QObject>
 
@@ -17,13 +15,11 @@ class LunarManager : public QObject
 public:
     explicit LunarManager(QObject *parent = nullptr);
     static LunarManager* instace();
-    bool huangLiDay(quint32 year, quint32 month, quint32 day, CaHuangLiDayInfo &info);
-    bool huangLiDay(const QDate &date, CaHuangLiDayInfo &out);
-    CaHuangLiDayInfo huangLiDay(const QDate &date);
 
-private:
-    LunarDBusInterface* m_dbusInter;                   //dbus请求实例
-    QMap<QDate, CaHuangLiDayInfo> m_lunarInfoMap;      //缓存的农历数据
+    void asyncRequestLunar(const QDate &date);
+
+Q_SIGNALS:
+    void lunarInfoReady(const CaHuangLiDayInfo &info);
 
 };
 #define gLunarManager LunarManager::instace()
