@@ -8,7 +8,8 @@
 #include "jumpcalendarbutton.h"
 #include "regionFormat.h"
 
-#include <DApplicationHelper>
+#include <DPaletteHelper>
+#include <DGuiApplicationHelper>
 #include <DFontSizeManager>
 #include <DRegionMonitor>
 #include <DToolTip>
@@ -16,7 +17,6 @@
 #include <QMouseEvent>
 #include <QScreen>
 #include <QJsonObject>
-#include <QtConcurrent/QtConcurrentRun>
 
 SidebarCalendarWidget::SidebarCalendarWidget(RegionFormat *regionFormat, QWidget* parent)
     : QWidget(parent)
@@ -27,8 +27,8 @@ SidebarCalendarWidget::SidebarCalendarWidget(RegionFormat *regionFormat, QWidget
     , m_keyWidget(new QWidget(this))
     , m_keyLayout(new QGridLayout)
     , m_dateLabel(new QLabel(this))
-    , m_nextPage(new DPushButton(this))
-    , m_previousPage(new DPushButton(this))
+    , m_nextPage(new DIconButton(this))
+    , m_previousPage(new DIconButton(this))
     , m_firstday(Qt::Sunday)
     , m_dateTitleWidget(new DateTitleWidget(this))
     , m_weekLabel(new DLabel(this))
@@ -49,10 +49,6 @@ SidebarCalendarWidget::SidebarCalendarWidget(RegionFormat *regionFormat, QWidget
     initData();
 }
 
-SidebarCalendarWidget::~SidebarCalendarWidget()
-{
-}
-
 void SidebarCalendarWidget::initView()
 {
     setFocusPolicy(Qt::NoFocus);
@@ -89,12 +85,10 @@ void SidebarCalendarWidget::initView()
     DFontSizeManager::instance()->bind(m_dateLabel, DFontSizeManager::T5, 65);
     m_nextPage->setIcon(DStyle().standardIcon(QStyle::SP_ArrowRight));
     m_previousPage->setIcon(DStyle().standardIcon(QStyle::SP_ArrowLeft));
-    m_nextPage->setIconSize(QSize(15, 15));
-    m_previousPage->setIconSize(QSize(15, 15));
-    m_nextPage->setMinimumSize(30, 30);
-    m_previousPage->setMinimumSize(30, 30);
-    m_nextPage->setFlat(true);
-    m_previousPage->setFlat(true);
+    m_nextPage->setIconSize(QSize(12, 12));
+    m_previousPage->setIconSize(QSize(12, 12));
+    m_nextPage->setFixedSize(30, 30);
+    m_previousPage->setFixedSize(30, 30);
 
     m_nextPage->setFocusPolicy(Qt::NoFocus);
     m_previousPage->setFocusPolicy(Qt::NoFocus);
@@ -119,7 +113,7 @@ void SidebarCalendarWidget::initView()
     m_weekWidget->setMinimumHeight(20);
     DFontSizeManager::instance()->bind(m_weekWidget, DFontSizeManager::T6, 60);
 
-    m_keyLayout->setMargin(0);
+    m_keyLayout->setContentsMargins(0, 0, 0, 0);
     m_keyLayout->setSpacing(0);
     m_keyWidget->setLayout(m_keyLayout);
     //循坏实例化6*7个日期按键
@@ -132,7 +126,7 @@ void SidebarCalendarWidget::initView()
     }
 
     QHBoxLayout* mainLayout = new QHBoxLayout;
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
 
     rightLayout->addSpacing(6);
     rightLayout->addWidget(m_headWidget);
@@ -177,12 +171,13 @@ void SidebarCalendarWidget::initConnection()
 
         backToday();
     });
-
-    connect(qApp, &QApplication::fontChanged, this, [this]() {
-        m_jumpCalendarButton->setFixedWidth(m_jumpCalendarButton->sizeHint().width());
-        update();
+    connect(LunarManager::instace(), &LunarManager::lunarInfoReady, [this](const CaHuangLiDayInfo &info) {
+        m_lunarLabel->setText(tr("Lunar") + info.mLunarMonthName + info.mLunarDayName);
+        m_lunarDetailLabel->setText(info.mGanZhiYear + tr("y") + "【"
+                                    + info.mZodiac + tr("y") + "】"
+                                    + info.mGanZhiMonth + tr("m") + " "
+                                    + info.mGanZhiDay + tr("d"));
     });
-    connect(this, &SidebarCalendarWidget::serviceStateChanged, this, &SidebarCalendarWidget::setLunarVisible);
 }
 
 /**
@@ -204,9 +199,8 @@ void SidebarCalendarWidget::initData()
  */
 void SidebarCalendarWidget::setSelectedDate(const QDate &date)
 {
-    if(m_selectedData == date && (!m_huangliInfo.isEmpty() && !m_huangliInfo[0].isEmpty())) {
+    if(m_selectedData == date)
         return;
-    }
 
     m_selectedData = date;
     setDate(date);
@@ -225,29 +219,11 @@ void SidebarCalendarWidget::setDate(const QDate &date)
 
     m_bakTodayBtn->setVisible(date.month() != QDate::currentDate().month() || date.year() != QDate::currentDate().year());
 
-    auto huangliDay = LunarManager::instace()->huangLiDay(date);
-
-    QString lunarDateName = huangliDay.mLunarMonthName + huangliDay.mLunarDayName;
-    QString zodiac        = huangliDay.mZodiac;
-    QString ganzhiYear    = huangliDay.mGanZhiYear;
-    QString ganzhiMonth   = huangliDay.mGanZhiMonth;
-    QString ganzhiDay     = huangliDay.mGanZhiDay;
-
-    m_huangliInfo.clear();
-    m_huangliInfo << lunarDateName << zodiac << ganzhiYear << ganzhiMonth << ganzhiDay;
-
     m_dateTitleWidget->setDateLabelText("/ " + formatedMonth(static_cast<Month>(date.month())), date.day());
     m_weekLabel->setText(formatedWeekDay(static_cast<WeekDay>(date.dayOfWeek()), m_weekdayFormat));
     m_leftdateLabel->setText(date.toString(m_regionFormat->originShortDateFormat()));
     m_dateLabel->setText(formatedMonth(static_cast<Month>(date.month())));
-
-    m_lunarLabel->setText(tr("Lunar") + m_huangliInfo[0]);
-    m_lunarDetailLabel->setText(m_huangliInfo[1] + tr("y") + "【"
-                              + m_huangliInfo[2] + tr("y") + "】"
-                              + m_huangliInfo[3] + tr("m") + " "
-                              + m_huangliInfo[4] + tr("d"));
-
-    setLunarVisible(!lunarDateName.isEmpty() && !zodiac.isEmpty() && !ganzhiYear.isEmpty() && !ganzhiMonth.isEmpty() && !ganzhiDay.isEmpty());
+    LunarManager::instace()->asyncRequestLunar(date);
 
     if (m_displayedMonth != date) {
         m_displayedMonth = date;
@@ -380,25 +356,6 @@ void SidebarCalendarWidget::backToday()
     setSelectedDate(date);
 }
 
-void SidebarCalendarWidget::setLunarVisible(bool visible)
-{
-    const bool isChinese = QLocale::system().language() == QLocale::Language::Chinese;
-    m_lunarLabel->setVisible(isChinese && visible);
-    m_lunarDetailLabel->setVisible(isChinese && visible);
-    m_jumpCalendarButton->setVisible(visible);
-}
-
-void SidebarCalendarWidget::checkService()
-{
-    QtConcurrent::run([this]() {
-        const CaHuangLiDayInfo &day = LunarManager::instace()->huangLiDay(QDate::currentDate());
-        const bool isLunarValid = !day.mLunarMonthName.isEmpty() && !day.mLunarDayName.isEmpty();
-        const bool isLunarDetailValid = !day.mGanZhiYear.isEmpty() && !day.mGanZhiMonth.isEmpty() && !day.mGanZhiDay.isEmpty() && !day.mZodiac.isEmpty();
-        const bool isServiceValid = isLunarValid && isLunarDetailValid;
-        Q_EMIT serviceStateChanged(isServiceValid);
-    });
-}
-
 void SidebarCalendarWidget::hideEvent(QHideEvent *event)
 {
     QWidget::hideEvent(event);
@@ -406,15 +363,16 @@ void SidebarCalendarWidget::hideEvent(QHideEvent *event)
 
 void SidebarCalendarWidget::showEvent(QShowEvent *event)
 {
-    checkService();
-
+    bool showLunar = QLocale::system().language() == QLocale::Language::Chinese;
+    m_lunarLabel->setVisible(showLunar);
+    m_lunarDetailLabel->setVisible(showLunar);
     backToday();
     QWidget::showEvent(event);
 }
 
 void SidebarCalendarWidget::wheelEvent(QWheelEvent *event)
 {
-    m_deltaSum += event->delta();
+    m_deltaSum += event->angleDelta().y();
     if (m_deltaSum >= TURNPAGE_DELTA) {
         Q_EMIT m_previousPage->clicked();
         m_deltaSum = 0;
@@ -425,6 +383,16 @@ void SidebarCalendarWidget::wheelEvent(QWheelEvent *event)
     QWidget::wheelEvent(event);
 }
 
+bool SidebarCalendarWidget::event(QEvent *event)
+{
+    if (event->type() == QEvent::ApplicationFontChange) {
+        m_jumpCalendarButton->setFixedWidth(m_jumpCalendarButton->sizeHint().width());
+        update();
+    }
+
+    return QWidget::event(event);
+}
+
 QString SidebarCalendarWidget::formatedWeekDay(WeekDay weekDay, CalendarManager::WeekDayFormat format)
 {
     if (QLocale::system().language() == QLocale::English)
@@ -547,7 +515,7 @@ void SidebarCalendarKeyButton::paintEvent(QPaintEvent* event)
 
     QStyleOption opt;
     opt.initFrom(this);
-    auto pa = DApplicationHelper::instance()->palette(this);
+    auto pa = DPaletteHelper::instance()->palette(this);
 
     if (opt.state & QStyle::StateFlag::State_MouseOver) {
         painter.setPen(Qt::NoPen);
