@@ -10,7 +10,7 @@
 #include "calendarmanager.h"
 
 #include <DLabel>
-#include <DPushButton>
+#include <DIconButton>
 #include <DFontSizeManager>
 #include <DCommandLinkButton>
 
@@ -54,13 +54,11 @@ class SidebarCalendarWidget : public QWidget
     Q_OBJECT
 public:
     explicit SidebarCalendarWidget(RegionFormat *regionFormat, QWidget *parent = nullptr);
-    ~SidebarCalendarWidget() override;
     //设置选中的日期
     void setSelectedDate(const QDate &date);
 
 signals:
     void jumpButtonClicked();
-    void serviceStateChanged(bool valid);
 
 private slots:
     //日期按键点击事件
@@ -75,13 +73,12 @@ private slots:
     void onWeekDayFormatChanged(CalendarManager::WeekDayFormat format);
     void backToday();
     void onShortDateFormatChanged();
-    void setLunarVisible(bool visible);
-    void checkService();
 
 protected:
     void hideEvent(QHideEvent *event) override;
     void showEvent(QShowEvent *event) override;
     void wheelEvent(QWheelEvent *event) override;
+    bool event(QEvent *event) override;
 
 private:
     void initView();
@@ -102,8 +99,8 @@ private:
     QWidget* m_keyWidget;                               //日期按钮区域控件
     QGridLayout* m_keyLayout;                           //按钮布局
     QLabel* m_dateLabel;                                //头部日期显示label
-    DPushButton* m_nextPage;                            //下一页切换按键
-    DPushButton* m_previousPage;                        //上一页切换按键
+    DIconButton* m_nextPage;                            //下一页切换按键
+    DIconButton* m_previousPage;                        //上一页切换按键
     QList<SidebarCalendarKeyButton*> m_keyButtonList;   //所有的日期按钮控件
     int m_firstday;
     DateTitleWidget *m_dateTitleWidget;
@@ -120,7 +117,6 @@ private:
     CalendarManager::WeekDayFormat m_weekdayFormat;
     int m_deltaSum;
     QTimer *m_timer;
-    QList<QString> m_huangliInfo;
 };
 
 
