@@ -15,6 +15,8 @@
 #include <DFontSizeManager>
 
 #define PLUGIN_STATE_KEY    "enable"
+#define DEFAULT_WEEK_FORMAT "dddd"
+#define SIMPLE_WEEK_FORMAT "ddd"
 
 DWIDGET_USE_NAMESPACE
 
@@ -27,14 +29,20 @@ DatetimeWidget::DatetimeWidget(RegionFormat* regionFormat, QWidget *parent)
     , m_24HourFormat(false)
     , m_weekdayFormatType(0)
     , m_shortDateFormat("yyyy-MM-dd")
+    , m_weekFormat(DEFAULT_WEEK_FORMAT)
     , m_dockSize(QSize(1920, 37))
+    , m_timedateInter(new Timedate1Inter("org.deepin.dde.Timedate1", "/org/deepin/dde/Timedate1", QDBusConnection::sessionBus(), this))
     , m_regionFormat(regionFormat)
 {
     initUI();
 
+    setWeekdayFormat(m_timedateInter->weekdayFormat());
+    connect(m_timedateInter, &Timedate1Inter::WeekdayFormatChanged, this, &DatetimeWidget::setWeekdayFormat);
+
     m_24HourFormat = m_regionFormat->is24HourFormat();
     adjustFontSize();
     updateDateTimeString();
+    installEventFilter(this);
 
     connect(m_regionFormat, &RegionFormat::longDateFormatChanged, this, &DatetimeWidget::updateDateTime);
     connect(m_regionFormat, &RegionFormat::shortTimeFormatChanged, this, &DatetimeWidget::updateDateTime);
@@ -58,39 +66,6 @@ void DatetimeWidget::set24HourFormat(const bool value)
     }
 }
 
-/**
- * @brief DatetimeWidget::setShortDateFormat 根据类型设置时间显示格式
- * @param type 自定义类型
- */
-void DatetimeWidget::setShortDateFormat(int type)
-{
-    const Dock::Position position = qApp->property(PROP_POSITION).value<Dock::Position>();
-
-    // 任务栏在左/右的时候不显示年份
-    const bool removeY = (position == Dock::Top || position == Dock::Bottom) ? false : true;
-    switch (type) {
-    case 0: removeY ? m_shortDateFormat = "M/d" : m_shortDateFormat = "yyyy/M/d"; break;
-    case 1: removeY ? m_shortDateFormat = "M-d" : m_shortDateFormat = "yyyy-M-d"; break;
-    case 2: removeY ? m_shortDateFormat = "M.d" : m_shortDateFormat = "yyyy.M.d"; break;
-    case 3: removeY ? m_shortDateFormat = "MM/dd" : m_shortDateFormat = "yyyy/MM/dd"; break;
-    case 4: removeY ? m_shortDateFormat = "MM-dd" : m_shortDateFormat = "yyyy-MM-dd"; break;
-    case 5: removeY ? m_shortDateFormat = "MM.dd" : m_shortDateFormat = "yyyy.MM.dd"; break;
-    case 6: removeY ? m_shortDateFormat = "MM.dd" : m_shortDateFormat = "MM.dd.yyyy"; break;
-    case 7: removeY ? m_shortDateFormat = "dd.MM" : m_shortDateFormat = "dd.MM.yyyy"; break;
-    case 8: removeY ? m_shortDateFormat = "M/d" : m_shortDateFormat = "yy/M/d"; break;
-    case 9: removeY ? m_shortDateFormat = "M-d" : m_shortDateFormat = "yy-M-d"; break;
-    case 10: removeY ? m_shortDateFormat = "M.d" : m_shortDateFormat = "yy.M.d"; break;
-    default: removeY ? m_shortDateFormat = "MM-dd" : m_shortDateFormat = "yyyy-MM-dd"; break;
-    }
-
-    update();
-
-    if (isVisible()) {
-        emit requestUpdateGeometry();
-    }
-}
-
-
 /**
  * @brief DatetimeWidget::setWeekdayFormat 根据类型设置周显示格式
  * @param type 自定义类型
@@ -110,63 +85,10 @@ void DatetimeWidget::setWeekdayFormat(int type)
  */
 void DatetimeWidget::updateWeekdayFormat()
 {
-    const QDateTime currentDateTime = QDateTime::currentDateTime();
-    auto dayOfWeek = currentDateTime.date().dayOfWeek();
-
-    if (0 == m_weekdayFormatType) {
-        switch (dayOfWeek) {
-        case 1:
-            m_weekFormat = tr("Monday"); //星期一
-            break;
-        case 2:
-            m_weekFormat = tr("Tuesday"); //星期二
-            break;
-        case 3:
-            m_weekFormat = tr("Wednesday"); //星期三
-            break;
-        case 4:
-            m_weekFormat = tr("Thursday"); //星期四
-            break;
-        case 5:
-            m_weekFormat = tr("Friday"); //星期五
-            break;
-        case 6:
-            m_weekFormat = tr("Saturday"); //星期六
-            break;
-        case 7:
-            m_weekFormat = tr("Sunday"); //星期天
-            break;
-        default:
-            m_weekFormat = tr("Monday"); //星期一
-            break;
-        }
+    if (1 == m_weekdayFormatType) {
+        m_weekFormat = SIMPLE_WEEK_FORMAT;
     } else {
-        switch (dayOfWeek) {
-        case 1:
-            m_weekFormat = tr("monday"); //周一
-            break;
-        case 2:
-            m_weekFormat = tr("tuesday"); //周二
-            break;
-        case 3:
-            m_weekFormat = tr("wednesday"); //周三
-            break;
-        case 4:
-            m_weekFormat = tr("thursday"); //周四
-            break;
-        case 5:
-            m_weekFormat = tr("friday"); //周五
-            break;
-        case 6:
-            m_weekFormat = tr("saturday"); //周六
-            break;
-        case 7:
-            m_weekFormat = tr("sunday"); //周天
-            break;
-        default:
-            m_weekFormat = tr("monday"); //周一
-            break;
-        }
+        m_weekFormat = DEFAULT_WEEK_FORMAT;
     }
 }
 
@@ -181,28 +103,28 @@ void DatetimeWidget::setRegionFormat(RegionFormat *newRegionFormat)
 void DatetimeWidget::updateDateTimeString()
 {
     QLocale locale(m_regionFormat->getLocaleName());
-    m_dateTime = locale.toString(QDate::currentDate(), m_regionFormat->getLongDateFormat()) + " " + QDateTime::currentDateTime().toString(m_regionFormat->getLongTimeFormat());
+
+    QString longDateFormat = m_regionFormat->getLongDateFormat();
+    longDateFormat.replace(DEFAULT_WEEK_FORMAT, m_weekFormat, Qt::CaseInsensitive);
+    m_dateTime = locale.toString(QDateTime::currentDateTime(), longDateFormat + " " + m_regionFormat->getLongTimeFormat());
 
     QDateTime current = QDateTime::currentDateTime();
 
     const auto position = qApp->property(PROP_POSITION).value<Dock::Position>();
     QString timeStr, dateString;
     if (position == Dock::Bottom || position == Dock::Top) {
-        if (!m_24HourFormat) {
-            timeStr = current.toString(m_regionFormat->getShortTimeFormat());
-        } else {
-            timeStr = current.toString("hh:mm");
-        }
+        QString timeFormat = m_24HourFormat ? "hh:mm" : m_regionFormat->getShortTimeFormat();
+        timeStr = locale.toString(current, timeFormat);
         dateString = current.toString(m_regionFormat->getShortDateFormat());
 
         m_timeLabel->setText(timeStr);
         m_dateLabel->setText(dateString);
     } else {
         if (!m_24HourFormat) {
-            QString apText = current.toString("AP");
+            QString apText = locale.toString(current, "AP");
             m_apLabel->setText(apText);
 
-            timeStr = current.toString("AP h:mm").split(" ").at(1);
+            timeStr = current.toString("h:mm");
         } else {
             timeStr = current.toString("hh:mm");
         }
@@ -211,13 +133,6 @@ void DatetimeWidget::updateDateTimeString()
         dateString = current.toString(m_regionFormat->getShortDateFormat());
         m_dateLabel->setText(dateString);
     }
-
-#if 0 // for debug
-    m_timeLabel->setStyleSheet("background-color: red;");
-    m_dateLabel->setStyleSheet("background-color: blue;");
-    QFontMetrics fontMetrics(m_timeLabel->font());
-    qInfo() << "timeLabel font height:" << fontMetrics.height() << " sizeHint:" << m_timeLabel->sizeHint();;
-#endif
 }
 
 void DatetimeWidget::updateDateTime()
@@ -235,9 +150,9 @@ void DatetimeWidget::updateDateTime()
 void DatetimeWidget::adjustFontSize()
 {
     const auto position = qApp->property(PROP_POSITION).value<Dock::Position>();
-    int validDistance = m_dockSize.height() / qApp->devicePixelRatio();
+    int validDistance = m_dockSize.height() / devicePixelRatioF();
     if (position == Dock::Left || position == Dock::Right) {
-        validDistance = m_dockSize.width() / qApp->devicePixelRatio();
+        validDistance = m_dockSize.width() / devicePixelRatioF();
     }
 
     // 根据时间和日期字体大小的跨度，将dock栏大小分为不同的区间，每个区域对应不同的字体大小，然后通过判断dock栏大小所在的区间来设置字体大小
@@ -255,7 +170,7 @@ void DatetimeWidget::adjustFontSize()
         {61, {20, 14}},
         {999, {20, 14}}
     };
-    
+
     int timeFontSize = 0;
     int dateFontSize = 0;
     QList<int> distances = fontSizeMap.keys();
@@ -287,6 +202,15 @@ void DatetimeWidget::resizeEvent(QResizeEvent *event)
     QWidget::resizeEvent(event);
 }
 
+bool DatetimeWidget::eventFilter(QObject *watched, QEvent *event)
+{
+    if (event->type() == QEvent::DevicePixelRatioChange && watched == this) {
+        adjustFontSize();
+    }
+
+    return QWidget::eventFilter(watched, event);
+}
+
 void DatetimeWidget::setDockPanelSize(const QSize &dockSize)
 {
     // 任务栏高度最小是37，小于37说明在隐藏和显示动画中
@@ -314,6 +238,7 @@ void DatetimeWidget::dockPositionChanged()
     });
 
     adjustUI();
+    adjustFontSize();
 }
 
 void DatetimeWidget::initUI()
@@ -335,7 +260,6 @@ void DatetimeWidget::initUI()
     m_apLabel->setForegroundRole(QPalette::BrightText);
 
     auto *layout = new QVBoxLayout();
-    layout->setMargin(0);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     layout->addWidget(m_apLabel);
@@ -361,4 +285,4 @@ void DatetimeWidget::adjustUI()
 
     m_spacerItem->setVisible(false);
     m_apLabel->setVisible(false);
-}
+}
\ No newline at end of file
