@@ -53,7 +53,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -387,61 +387,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>በ ዘመናዊ ዘዴ</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>በ አጥጋቢ ዘዴ</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>ከ ላይ</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>ከ ታች</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>የ ግራ</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>የ ቀኝ</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>እንደ ታየ ማቆያ</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>እንደ ተደበቅ ማቆያ</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>በራሱ መደበቂያ</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>ዘዴ</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>አካባቢ</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>ሁኔታው</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
