@@ -51,7 +51,7 @@
         <translation>Vypnuto</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -385,61 +385,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Líbivý režim</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Účelný režim</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Nahoře</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Dole</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Vlevo</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Vpravo</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Vždy zobrazeno</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Vždy skryto</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Chytré skrývání</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Režim</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Umístění</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Stav</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>Nastavení panelu</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
