@@ -15,7 +15,7 @@
     </message>
     <message>
         <source>Enable</source>
-        <translation>Permitir</translation>
+        <translation>Activar</translation>
     </message>
     <message>
         <source>Airplane Mode</source>
@@ -51,8 +51,8 @@
         <translation>Desactivado</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
-        <translation>Desactive primero el modo avión si desea conectarse a un Bluetooth</translation>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
+        <translation>Desactive el [Modo avión](#) si desea conectarse a un dispositivo Bluetooth.</translation>
     </message>
 </context>
 <context>
@@ -113,14 +113,14 @@
     </message>
     <message>
         <source>Display settings</source>
-        <translation>Ajustes de Pantalla</translation>
+        <translation>Ajustes de pantalla</translation>
     </message>
 </context>
 <context>
     <name>BrightnessItem</name>
     <message>
         <source>Display settings</source>
-        <translation>Ajustes de Pantalla</translation>
+        <translation>Ajustes de pantalla</translation>
     </message>
 </context>
 <context>
@@ -134,31 +134,31 @@
     <name>CWeekWidget</name>
     <message>
         <source>Sun</source>
-        <translation>dom.</translation>
+        <translation>Dom</translation>
     </message>
     <message>
         <source>Mon</source>
-        <translation>lun.</translation>
+        <translation>Lun</translation>
     </message>
     <message>
         <source>Tue</source>
-        <translation>mar.</translation>
+        <translation>Mar</translation>
     </message>
     <message>
         <source>Wed</source>
-        <translation>miérc.</translation>
+        <translation>Mié</translation>
     </message>
     <message>
         <source>Thu</source>
-        <translation>juev.</translation>
+        <translation>Jue</translation>
     </message>
     <message>
         <source>Fri</source>
-        <translation>vier.</translation>
+        <translation>Vie</translation>
     </message>
     <message>
         <source>Sat</source>
-        <translation>sáb.</translation>
+        <translation>Sáb</translation>
     </message>
 </context>
 <context>
@@ -195,31 +195,31 @@
     <name>DatetimeWidget</name>
     <message>
         <source>Monday</source>
-        <translation>lunes</translation>
+        <translation>Lunes</translation>
     </message>
     <message>
         <source>Tuesday</source>
-        <translation>martes</translation>
+        <translation>Martes</translation>
     </message>
     <message>
         <source>Wednesday</source>
-        <translation>miércoles</translation>
+        <translation>Miércoles</translation>
     </message>
     <message>
         <source>Thursday</source>
-        <translation>jueves</translation>
+        <translation>Jueves</translation>
     </message>
     <message>
         <source>Friday</source>
-        <translation>viernes</translation>
+        <translation>Viernes</translation>
     </message>
     <message>
         <source>Saturday</source>
-        <translation>sábado</translation>
+        <translation>Sábado</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>domingo</translation>
+        <translation>Domingo</translation>
     </message>
     <message>
         <source>monday</source>
@@ -261,11 +261,11 @@
     <name>DndModeItem</name>
     <message>
         <source>DND Mode</source>
-        <translation>Modo DND</translation>
+        <translation>Modo no molestar</translation>
     </message>
     <message>
         <source>DND mode settings</source>
-        <translation>Ajustes de modo DND</translation>
+        <translation>Ajustes de modo no molestar</translation>
     </message>
     <message>
         <source>Disable</source>
@@ -277,18 +277,18 @@
     </message>
     <message>
         <source>DND mode enabled</source>
-        <translation>Modo DND activado</translation>
+        <translation>Modo no molestar activado</translation>
     </message>
     <message>
         <source>DND mode disabled</source>
-        <translation>Modo DND desactivado</translation>
+        <translation>Modo no molestar desactivado</translation>
     </message>
 </context>
 <context>
     <name>DndModePlugin</name>
     <message>
         <source>DND Mode</source>
-        <translation>Modo DND</translation>
+        <translation>Modo no molestar</translation>
     </message>
 </context>
 <context>
@@ -307,7 +307,7 @@
     </message>
     <message>
         <source>Display settings</source>
-        <translation>Ajustes de Pantalla</translation>
+        <translation>Ajustes de pantalla</translation>
     </message>
     <message>
         <source>Eye comfort</source>
@@ -359,7 +359,7 @@
     </message>
     <message>
         <source>Theme: Auto</source>
-        <translation>Tema: Automatico</translation>
+        <translation>Tema: Automático</translation>
     </message>
     <message>
         <source>Visual effect</source>
@@ -385,61 +385,6 @@
         <translation>Tema</translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Modo elegante</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Modo eficiente</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Arriba</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Abajo</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Izquierda</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Derecha</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Mantener visible</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Mantener oculto</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Ocultado inteligente</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Modo</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Ubicación</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Estado</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>Ajustes del muelle</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
@@ -456,11 +401,11 @@
     </message>
     <message>
         <source>Turn off DND mode</source>
-        <translation>Desactivar el modo DND</translation>
+        <translation>Desactivar el modo no molestar</translation>
     </message>
     <message>
         <source>Turn on DND mode</source>
-        <translation>Activar el modo DND</translation>
+        <translation>Activar el modo no molestar</translation>
     </message>
     <message>
         <source>Notification</source>
@@ -572,7 +517,7 @@
     </message>
     <message>
         <source>Fully charged</source>
-        <translation>Carga llena</translation>
+        <translation>Completamente cargada</translation>
     </message>
     <message>
         <source>Charging, %1 min until full</source>
@@ -649,11 +594,11 @@
     </message>
     <message>
         <source>Update and Shut Down</source>
-        <translation>Actualizar y Apagar</translation>
+        <translation>Actualizar y apagar</translation>
     </message>
     <message>
         <source>Update and Reboot</source>
-        <translation>Actualizar y Reiniciar</translation>
+        <translation>Actualizar y reiniciar</translation>
     </message>
     <message>
         <source>Shut Down</source>
