@@ -53,7 +53,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -387,61 +387,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>ഫാഷൻ രീതി</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>കാര്യക്ഷമമായ രീതി</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>മുകളിൽ</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>താഴെ</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>ഇടതു്</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>വലതു്</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>എപ്പോഴും ദൃശ്യമാക്കുക</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>എപ്പോഴും അദൃശ്യമാക്കുക</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>സമർത്ഥമായ അദൃശ്യമാക്കൽ</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>രീതി</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>സ്ഥാനം</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>അവസ്ഥ</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
