@@ -53,7 +53,7 @@
         <translation type="unfinished">Oprit</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -387,61 +387,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Mod aspectuos</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Mod eficient</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Sus</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Jos</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Stânga</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Dreapta</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Păstrați docul afișat</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Păstrați docul ascuns</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Ascundere inteligentă</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Mod</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Locație</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Stare</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
