@@ -5,11 +5,10 @@
 #include "roundscrollarea.h"
 
 #include <QPainter>
-#include <QDebug>
 #include <QPainterPath>
 
 #include <DPalette>
-#include <DApplicationHelper>
+#include <DPaletteHelper>
 
 DWIDGET_USE_NAMESPACE
 
@@ -17,9 +16,9 @@ RoundScrollArea::RoundScrollArea(QWidget *parent)
     : QScrollArea(parent)
     , m_radius(18)
 {
-    DPalette pa = DApplicationHelper::instance()->palette(this);
+    DPalette pa = DPaletteHelper::instance()->palette(this);
     pa.setBrush(DPalette::Window, Qt::transparent);
-    DApplicationHelper::instance()->setPalette(this, pa);
+    DPaletteHelper::instance()->setPalette(this, pa);
 }
 
 void RoundScrollArea::setRadius(int radius)
@@ -36,5 +35,5 @@ void RoundScrollArea::paintEvent(QPaintEvent *e)
     QPainterPath path;
     path.addRoundedRect(viewport()->rect(), m_radius, m_radius);
     painter.setClipPath(path);
-    painter.fillPath(path, palette().background());
+    painter.fillPath(path, palette().window());
 }
