@@ -11,18 +11,13 @@
 #include <QMouseEvent>
 #include <QMenu>
 
-#include <DFontSizeManager>
-
-DWIDGET_USE_NAMESPACE
-
 const static QString DockQuickPlugins = "Dock_Quick_Plugins";
 
 PluginItem::PluginItem(PluginsItemInterface *pluginItemInterface, const QString &itemKey, QWidget *parent)
     : QWidget(parent)
     , m_pluginsItemInterface(pluginItemInterface)
-    , m_pluginsItemInterfacev2(dynamic_cast<PluginsItemInterfaceV2*>(pluginItemInterface))
     , m_itemKey(itemKey)
-    , m_menu(new QMenu(this))
+    , m_menu(new QMenu)
     , m_tooltipTimer(new QTimer(this))
     , m_tipsWidget(nullptr)
 {
@@ -34,6 +29,11 @@ PluginItem::PluginItem(PluginsItemInterface *pluginItemInterface, const QString
 
     connect(m_menu, &QMenu::triggered, this, [this](QAction *action){
         QString actionStr = action->data().toString();
+        if (actionStr.startsWith(Dock::SHUTDOWN_MENU_FLAG)) {
+            handleShutDownMenu(actionStr);
+            return;
+        }
+
         if (actionStr == Dock::dockMenuItemId || actionStr == Dock::unDockMenuItemId) {
             m_dbusProxy->setItemOnDock(DockQuickPlugins, m_itemKey, actionStr == Dock::dockMenuItemId);
         } else {
@@ -151,7 +151,7 @@ void PluginItem::mouseReleaseEvent(QMouseEvent *e)
     QWidget::mouseReleaseEvent(e);
 }
 
-void PluginItem::enterEvent(QEvent *event)
+void PluginItem::enterEvent(QEnterEvent *event)
 {
     // panel popup existed, not show tooltip
     if (panelPopupExisted()) {
@@ -162,7 +162,6 @@ void PluginItem::enterEvent(QEvent *event)
         if (auto pluginPopup = Plugin::PluginPopup::get(toolTip->windowHandle())) {
             auto plugin = Plugin::EmbedPlugin::get(windowHandle());
             auto geometry = plugin->pluginPos();
-            auto e = dynamic_cast<QEnterEvent *>(event);
             const auto offset = QPoint(width() / 2, height() / 2);
             pluginPopup->setX(geometry.x() + offset.x());
             pluginPopup->setY(geometry.y() + offset.y());
@@ -178,7 +177,7 @@ void PluginItem::enterEvent(QEvent *event)
     QWidget::enterEvent(event);
 }
 
-void PluginItem::moveEvent(QMoveEvent* e)
+void PluginItem::moveEvent(QMoveEvent *e)
 {
     if (auto popup = m_pluginsItemInterface->itemPopupApplet(m_itemKey); popup && popup->isVisible()) {
         if (auto pluginPopup = Plugin::PluginPopup::get(popup->windowHandle())) {
@@ -245,6 +244,15 @@ void PluginItem::updatePopupSize(const QRect &rect)
     }
 }
 
+void PluginItem::handleShutDownMenu(const QString &menuId)
+{
+    if (menuId.size() <= Dock::SHUTDOWN_MENU_FLAG.size())
+        return;
+
+    QString type = menuId.right(menuId.size() - Dock::SHUTDOWN_MENU_FLAG.size());
+    Q_EMIT sigRequestShutdown(type);
+}
+
 void PluginItem::init()
 {
     winId();
@@ -252,7 +260,7 @@ void PluginItem::init()
 
     auto hLayout = new QHBoxLayout;
     hLayout->addWidget(centralWidget());
-    hLayout->setMargin(0);
+    hLayout->setContentsMargins(0, 0, 0, 0);
     hLayout->setSpacing(0);
     hLayout->setSizeConstraint(QLayout::SetFixedSize);
 
@@ -306,7 +314,6 @@ QWidget * PluginItem::itemTooltip(const QString &itemKey)
         }
         m_tipsWidget = new QWidget();
         QVBoxLayout *layout = new QVBoxLayout(m_tipsWidget);
-        layout->setMargin(0);
         // add content margin, tooltip popup do not need to set padding
         layout->setContentsMargins(8, 4, 8, 4);
         layout->addWidget(toolTip);
@@ -324,10 +331,6 @@ QWidget * PluginItem::itemTooltip(const QString &itemKey)
     m_tipsWidget->setAttribute(Qt::WA_TranslucentBackground);
     m_tipsWidget->winId();
 
-    DFontSizeManager *fontManager =  DFontSizeManager::instance();
-    fontManager->bind(m_tipsWidget, DFontSizeManager::T7, QFont::Thin);
-
-    auto geometry = windowHandle()->geometry();
     auto pluginPopup = Plugin::PluginPopup::get(m_tipsWidget->windowHandle());
     pluginPopup->setPluginId(m_pluginsItemInterface->pluginName());
     pluginPopup->setItemKey(itemKey);
@@ -340,6 +343,12 @@ bool PluginItem::executeCommand()
     const QString command = m_pluginsItemInterface->itemCommand(m_itemKey);
     if (!command.isEmpty()) {
         qInfo() << "command: " << command;
+
+        if (command == Dock::REQUEST_SHUTDOWN) {
+            emit sigRequestShutdown(QString());
+            return true;
+        }
+
         QStringList commandList = command.split(" ");
         QString program = commandList.takeFirst(); // 剩下是参数
 
@@ -376,8 +385,8 @@ void PluginItem::closeToolTip()
         m_tooltipTimer->stop();
     }
 
-    if (m_tipsWidget && m_tipsWidget->windowHandle() && m_tipsWidget->windowHandle()->isVisible())
-        m_tipsWidget->windowHandle()->hide();
+    if (m_tipsWidget)
+        m_tipsWidget->hide();
 }
 
 void PluginItem::updatePluginContentMargin(int spacing)
