@@ -38,11 +38,12 @@ public:
 
 signals:
     void recvMouseEvent(int type);
+    void sigRequestShutdown(const QString &type);
 
 protected:
     void mousePressEvent(QMouseEvent *e) override;
     void mouseReleaseEvent(QMouseEvent *e) override;
-    void enterEvent(QEvent *event) override;
+    void enterEvent(QEnterEvent *event) override;
     void leaveEvent(QEvent *event) override;
     void moveEvent(QMoveEvent *e) override;
 
@@ -63,6 +64,7 @@ private:
 
 private:
     void updatePopupSize(const QRect &rect);
+    void handleShutDownMenu(const QString &menuId);
 
 protected:
     QString m_itemKey;
@@ -71,7 +73,6 @@ protected:
 
 private:
     PluginsItemInterface *m_pluginsItemInterface;
-    PluginsItemInterfaceV2 *m_pluginsItemInterfacev2;
     QTimer* m_tooltipTimer;
     QPointer<QWidget> m_tipsWidget;
 
